pub struct ChooseNodeRequest {
pub talk: Entity,
pub next: Entity,
}Expand description
An event to jump to some specific node in a graph. It requires an entity with the Talk component you want to update.
It is typically used when you want to go to a target node from a choice node.
The ActionId to jump to is the one defined in the next field for the Choice choosen by the player.
Fields
talk: EntityThe entity with the Talk component you want to update.
next: EntityThe next entity to go to.
Implementations